gen_xml_cli is a command line script for running the main
callback modules in the gen_xml package.
Copyright © 2025, Fred Youhanaie
Authors: Fred Youhanaie (fyrlang@anydata.co.uk).
gen_xml_cli is a command line script for running the main
callback modules in the gen_xml package.
| do_counts/1 | |
| do_null/1 | |
| do_paths/1 | |
| main/1 |
do_counts(Args) -> any()
do_null(Args) -> any()
do_paths(Args) -> any()
main(Args) -> any()
Generated by EDoc